@@ -1,5 +1,6 @@
 /*
 Copyright 2008-2014 Nick Shaforostoff <shaforostoff@kde.ru>
+                2018-2019 by Simon Depiets <sdepiets@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -184,8 +185,7 @@ QString GettextStorage::sourceWithPlurals(const DocPosition& pos, bool truncateF
         QString pluralString;
         for (int i = 0; i < plurals.size(); i++) {
             QString str = plurals.at(i);
-            if (truncateFirstLine)
-            {
+            if (truncateFirstLine) {
                 int truncatePos = str.indexOf("\n");
                 if (truncatePos != -1)
                     str.truncate(truncatePos);
@@ -198,8 +198,7 @@ QString GettextStorage::sourceWithPlurals(const DocPosition& pos, bool truncateF
         return pluralString;
     } else {
         QString str = m_entries.at(pos.entry).msgid(pos.form);
-        if (truncateFirstLine)
-        {
+        if (truncateFirstLine) {
             int truncatePos = str.indexOf("\n");
             if (truncatePos != -1)
                 str.truncate(truncatePos);
@@ -214,8 +213,7 @@ QString GettextStorage::targetWithPlurals(const DocPosition& pos, bool truncateF
         QString pluralString;
         for (int i = 0; i < plurals.size(); i++) {
             QString str = plurals.at(i);
-            if (truncateFirstLine)
-            {
+            if (truncateFirstLine) {
                 int truncatePos = str.indexOf("\n");
                 if (truncatePos != -1)
                     str.truncate(truncatePos);
@@ -228,8 +226,7 @@ QString GettextStorage::targetWithPlurals(const DocPosition& pos, bool truncateF
         return pluralString;
     } else {
         QString str = m_entries.at(pos.entry).msgstr(pos.form);
-        if (truncateFirstLine)
-        {
+        if (truncateFirstLine) {
             int truncatePos = str.indexOf("\n");
             if (truncatePos != -1)
                 str.truncate(truncatePos);
